
die "The Parser module is no longer a part of HTML::Mason.  Please see ".
    "the Lexer and Compiler modules, its replacements.\n";

1;  # heh

__END__

=pod

=head1 NAME

HTML::Mason::Parser - Old module for compiling components

=head1 DESCRIPTION

The Parser object is no longer part of Mason.  It has been replaced by
the Compiler and Lexer objects.  See the L<Developer's
Manual|HTML::Mason::Devel> and the L<Administrator's
Manual|HTML::Mason::Admin> for more details.

=cut
